# -*- coding: utf-8 -*-

from .. import utils

try:
    from django_jinja import library

    @library.global_function
    def sites_url(name, *args, **kwargs):
        site_id = kwargs.pop("site_id", None)
        return utils.reverse(name, args=args, kwargs=kwargs, site_id=site_id)

    @library.global_function
    def sites_static(path, site_id=None):
        return utils.static(path, site_id=site_id)
except ImportError:
    pass



# -*- coding: utf-8 -*-

from django.utils.functional import cached_property
from django.conf import settings

from . import exceptions


class Site(object):
    def __init__(self, config):
        self._config = config

    @cached_property
    def domain(self):
        try:
            domain = self._config.get("domain")
        except AttributeError:
            raise exceptions.SitesNotConfigured("site has wrong configuration")
        else:
            return domain

    @cached_property
    def scheme(self):
        scheme = self._config.get('scheme', None)
        if scheme is None:
            scheme = getattr(settings, "DJANGO_SITES_DEFAULT_SCHEME", "")
        return scheme

    @cached_property
    def name(self):
        try:
            name = self._config.get("name")
        except AttributeError:
            raise exceptions.SitesNotConfigured("site has wrong configuration")
        else:
            return name


def _get_sites_config():
    sites = getattr(settings, "SITES", None)
    if not sites:
        raise exceptions.SitesNotConfigured("SITES settings not found")
    return sites


def get_site_from_settings():
    """
    Get site instance from settings
    configuration.
    """
    sites = _get_sites_config()

    try:
        current_site_id = getattr(settings, "SITE_ID")
    except AttributeError:
        raise exceptions.SitesNotConfigured()

    if current_site_id not in sites:
        raise exceptions.SitesNotConfigured()

    return Site(sites[current_site_id])


def get_by_id(id):
    """
    Get site instance from settings configuration.
    """
    sites = _get_sites_config()

    try:
        return Site(sites[id])
    except KeyError:
        raise exceptions.SiteNotFound("Site with id '{}' not found".format(id))


def get_current():
    """
    Get current site.
    """
    return get_site_from_settings()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup
import sys


INSTALL_REQUIRES = [
    "django >=1.4",
]

if sys.version_info < (2, 7):
    INSTALL_REQUIRES.append('importlib')

setup(
    name = "django-sites",
    version = "0.10",
    description = "Alternative implementation of django sites framework",
    long_description = "",
    keywords = "django, sites",
    author = "Andrey Antukh",
    author_email = "niwi@niwi.nz",
    url = "https://github.com/niwinz/django-sites",
    license = "BSD",
    packages = [
        "django_sites",
        "django_sites.templatetags",
    ],

    install_requires = INSTALL_REQUIRES,
    classifiers = [
        "Development Status :: 4 - Beta",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Topic :: Internet :: WWW/HTTP",
    ]
)



# -*- coding: utf-8 -*-

from . import base


class SitesMiddleware(object):
    """
    Sites middleware. Attach current site instance to
    current request.
    """

    def process_request(self, request):
        request.site = base.get_current()



# -*- coding: utf-8 -*-

import unittest
import django

from django_sites.exceptions import SitesNotConfigured
from django_sites import base
from django_sites import utils

if django.VERSION[:2] < (1, 7):
    from django.test.utils import override_settings
else:
    from django.test import override_settings

if django.VERSION[:2] >= (1, 8):
    from django.template import engines
    env = engines["jinja2"]
else:
    from django_jinja.base import env


class BasicSitesTests(unittest.TestCase):
    @override_settings(SITES=None)
    def test_get_sites_config_01(self):
        with self.assertRaises(SitesNotConfigured):
            base._get_sites_config()

    def test_get_sites_config_02(self):
        config = base._get_sites_config()
        self.assertEqual(config, {
                "foo": {'domain': 'example1.com', 'name': 'example1.com', 'scheme': 'https'},
                "bar": {'domain': 'example2.com', 'name': 'example2.com'}
            })

    @override_settings(SITES=None)
    def test_get_current_site_01(self):
        with self.assertRaises(SitesNotConfigured):
            base.get_current()

    @override_settings(SITE_ID="foo")
    def test_get_current_site_02(self):
        site = base.get_current()
        self.assertEqual(site.domain, "example1.com")
        self.assertEqual(site.name, "example1.com")

    @override_settings(SITE_ID="foo")
    def test_get_current_site_03(self):
        site = base.get_current()
        self.assertEqual(site.scheme, "https")

    @override_settings(SITE_ID="bar")
    def test_get_current_site_04(self):
        site = base.get_current()
        self.assertEqual(site.domain, "example2.com")
        self.assertEqual(site.name, "example2.com")

    @override_settings(SITE_ID="bar")
    def test_get_current_site_05(self):
        site = base.get_current()
        self.assertEqual(site.scheme, "")

    @override_settings(SITE_ID="bar", DJANGO_SITES_DEFAULT_SCHEME="http")
    def test_get_current_site_06(self):
        site = base.get_current()
        self.assertEqual(site.scheme, "http")

    def test_get_by_id(self):
        site = base.get_by_id("bar")
        self.assertEqual(site.domain, "example2.com")
        self.assertEqual(site.name, "example2.com")


class JinjaTemplateTests(unittest.TestCase):
    @override_settings(SITE_ID="bar", DJANGO_SITES_DEFAULT_SCHEME="http")
    def test_template_sites_url_functions(self):
        url = env.from_string("{{ sites_url('foo') }}").render({})
        self.assertEqual(url, "http://example2.com/foo")

        url = env.from_string("{{ sites_url('foo', site_id='foo') }}").render({})
        self.assertEqual(url, "https://example1.com/foo")

    @override_settings(SITE_ID="bar", DJANGO_SITES_DEFAULT_SCHEME="http")
    def test_template_static_url_functions(self):
        url = env.from_string("{{ sites_static('lib.js') }}").render({})
        self.assertEqual(url, "http://example2.com/static/lib.js")

        url = env.from_string("{{ sites_static('libs.js', site_id='foo') }}").render({})
        self.assertEqual(url, "https://example1.com/static/libs.js")


class ReverseTests(unittest.TestCase):
    @override_settings(SITE_ID="bar")
    def test_reverse_01(self):
        url = utils.reverse("foo")
        self.assertEqual(url, "//example2.com/foo")

    @override_settings(SITE_ID="bar", DJANGO_SITES_DEFAULT_SCHEME="http")
    def test_reverse_02(self):
        url = utils.reverse("foo")
        self.assertEqual(url, "http://example2.com/foo")

    @override_settings(SITE_ID="foo", DJANGO_SITES_DEFAULT_SCHEME="http")
    def test_reverse_03(self):
        url = utils.reverse("foo")
        self.assertEqual(url, "https://example1.com/foo")

    def test_reverse_04(self):
        url = utils.reverse("foo", site_id="foo")
        self.assertEqual(url, "https://example1.com/foo")
        url = utils.reverse("foo", site_id="bar")
        self.assertEqual(url, "//example2.com/foo")



# -*- coding: utf-8 -*-

from django.contrib.staticfiles.templatetags.staticfiles import static as _static
from django.utils.functional import lazy

try:
    # For django >= 2.0
    from django.urls import reverse as _reverse
except ImportError:
    from django.core.urlresolvers import reverse as _reverse

from . import base


def reverse(viewname, args=None, kwargs=None, site_id=None):
    """
    Django-Sities version of reverse method that
    return full urls (with domain, protocol, etc...)
    """

    if site_id is None:
        site = base.get_current()
    else:
        site = base.get_by_id(site_id)

    url = _reverse(viewname, args=args, kwargs=kwargs)
    return get_absolute_url_for_site(url, site)


def static(path, site_id=None):
    url = _static(path)

    if url.startswith("http"):
        return url

    if site_id is None:
        site = base.get_current()
    else:
        site = base.get_by_id(site_id)

    return get_absolute_url_for_site(url, site)


def get_absolute_url_for_site(url, site):
    url_tmpl = "{scheme}//{domain}{url}"
    scheme = site.scheme and "{0}:".format(site.scheme) or ""
    return url_tmpl.format(scheme=scheme, domain=site.domain, url=url)


reverse_lazy = lazy(reverse, str)
static_lazy = lazy(static, str)
